require 'net/http'
require 'openssl'
require 'uri'
require 'json'
require 'faraday'

module Notifications
  class Uploader
    class << self
      def call(origin: nil, destination:, text:, link:, created_at: Time.now)
        message = JSON.generate(
          origin:     origin,
          text:       text,
          link:       link,
          read_at:    false,
          created_at: created_at.to_datetime.to_i
        )

        connection = Faraday.new(url: firebase_host)

        connection.post do |req|
          req.url "/notifications/#{destination}.json"
          req.headers['Content-Type'] = 'application/json'
          req.body = message
        end
      end

      private

      def firebase_host
        project_id = Notifications.configuration.firebase_project_id

        "https://#{project_id}.firebaseio.com"
      end
    end
  end
end
